use bevy::{
    prelude::*,
    sprite::{MaterialMesh2dBundle, Mesh2dHandle},
};
use bevy_rapier2d::prelude::*;
use drops::spawner_plugin;
const METER: f32 = 48.;

fn main() {
    let mut rapier_config = RapierConfiguration::new(METER * 2.5);
    rapier_config.timestep_mode = TimestepMode::Variable {
        max_dt: 1.0 / 60.0,
        time_scale: 1.0,
        substeps: 4,
    };
    App::new()
        .add_plugins(DefaultPlugins)
        // this does things with gravity
        .insert_resource(rapier_config)
        .add_plugins(RapierPhysicsPlugin::<NoUserData>::pixels_per_meter(METER))
        .add_plugins(RapierDebugRenderPlugin::default())
        .add_plugins((spawner_plugin))
        .add_systems(Startup, (scene::setup_scene, setup_cam, player::add_player))
        .add_systems(
            Update,
            (player::move_player, player::player_ground_collision),
        )
        .run()
}

fn setup_cam(mut commands: Commands) {
    commands.spawn(Camera2dBundle {
        transform: Transform::from_xyz(0., 4. * METER, 0.),
        ..default()
    });
}

mod drops;
mod player;
mod scene;
